.. py:currentmodule:: drdmannturb

API Reference
=============

This is the main reference for the forward-facing interface. 

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   fitting

.. raw:: html

    <hr>

.. toctree:: 
    :maxdepth: 1 

    windgeneration

